CallSiteExtras

Enum CallSiteExtras 

pub enum CallSiteExtras {
Show 13 variants None, Cpp { argument_count: usize, is_template_instantiation: bool, }, JavaScript { is_async: bool, uses_await: bool, http_method: Option<String>, http_endpoint: Option<String>, }, Python { is_async: bool, is_method: bool, uses_decorator: bool, }, Rust { is_async: bool, uses_await: bool, is_unsafe: bool, is_method: bool, is_unsafe_block: bool, }, Java { is_static: bool, }, Go { is_goroutine: bool, is_deferred: bool, is_builtin: bool, is_method: bool, }, C { is_function_pointer: bool, }, CSharp { is_async: bool, uses_await: bool, is_property_access: bool, }, Lua { is_method: bool, }, Perl { is_method: bool, }, Shell { is_builtin: bool, }, Groovy { is_closure: bool, },
}
Language-specific payloads attached to CallSiteMetadata.

Variants



None

No extra metadata for this call site.



Cpp

Additional details for C++ call sites.

Fields

argument_count: usize

Number of arguments passed in the call expression.

is_template_instantiation: bool

Whether the call came from a template instantiation.



JavaScript

Additional details for JavaScript/TypeScript call sites.

Fields

is_async: bool

Whether the call occurs inside an async function.

uses_await: bool

Whether the call expression uses the await keyword.

http_method: Option<String>

HTTP call metadata (fetch, axios, etc.) for cross-language edges.

http_endpoint: Option<String>

HTTP endpoint for cross-language edges.



Python

Additional details for Python call sites.

Fields

is_async: bool

Whether the function containing the call is declared async.

is_method: bool

Whether the call is to a method (vs a standalone function).

uses_decorator: bool

Whether the function has decorators applied (e.g., @staticmethod).



Rust

Additional details for Rust call sites.

Fields

is_async: bool

Whether the call occurs inside an async function.

uses_await: bool

Whether the call expression uses .await.

is_unsafe: bool

Whether the containing function is marked unsafe.

is_method: bool

Whether the call is a method call (receiver.method() or self.method()).

is_unsafe_block: bool

Whether the call occurs inside an unsafe {} block.



Java

Additional details for Java call sites.

Fields

is_static: bool

Whether the call occurs inside a static method.



Go

Additional details for Go call sites.

Fields

is_goroutine: bool

Whether this call is launched as a goroutine (go foo()).

is_deferred: bool

Whether this call is deferred (defer foo()).

is_builtin: bool

Whether this call is to a Go builtin function (make, new, len, etc.).

is_method: bool

Whether this call is a method call (receiver.Method()).



C

Additional details for C call sites.

Fields

is_function_pointer: bool

Whether the call is likely through a function pointer.



CSharp

Additional details for C# call sites.

Fields

is_async: bool

Whether the call occurs inside an async method.

uses_await: bool

Whether the call uses the await keyword.

is_property_access: bool

Whether the call is to a property (synthetic getter/setter).



Lua

Additional details for Lua call sites.

Fields

is_method: bool

Whether the call is to a method (colon syntax).



Perl

Additional details for Perl call sites.

Fields

is_method: bool

Whether the call is to a method.



Shell

Additional details for Shell call sites.

Fields

is_builtin: bool

Whether the call is a built-in command.



Groovy

Additional details for Groovy call sites.

Fields

is_closure: bool

Whether the call is to a closure.