Graph comparison and diff functionality.
This module provides tools for comparing two CodeGraph instances to detect symbol changes between different versions of code (e.g., git refs). Graph diff and comparison for semantic diff operations.
This module provides functionality for comparing two CodeGraph instances to detect symbol changes between different versions of code (e.g., git refs).
Structs
- Diff
Result - Result of a graph comparison.
- Diff
Summary - Summary statistics for a diff.
- Graph
Comparator - Compares two
CodeGraphinstances and produces change records. - Node
Change - A change record for a single symbol.
- Node
Location - Location information for a symbol.
Enums
- Change
Type - Type of change detected for a symbol.