GraphComparator

Struct GraphComparator 

pub struct GraphComparator { /* private fields */ }
Compares two CodeGraph instances and produces change records.

This comparator uses heuristic matching to detect renames and distinguishes between body changes and signature changes.

Example

use sqry_core::graph::diff::GraphComparator;
use sqry_core::graph::CodeGraph;
use std::sync::Arc;
use std::path::PathBuf;

let base_graph: Arc<CodeGraph> = // ... build graph for base version
let target_graph: Arc<CodeGraph> = // ... build graph for target version

let comparator = GraphComparator::new(
    base_graph,
    target_graph,
    PathBuf::from("/workspace"),
    PathBuf::from("/tmp/base-worktree"),
    PathBuf::from("/tmp/target-worktree"),
);

let result = comparator.compute_changes()?;
println!("Found {} changes", result.changes.len());

Implementations

Source

impl GraphComparator

pub fn new( base: Arc<CodeGraph>, target: Arc<CodeGraph>, workspace_root: PathBuf, base_worktree_path: PathBuf, target_worktree_path: PathBuf, ) -> Self

Creates a new graph comparator.

Arguments
  • base - CodeGraph for the base version
  • target - CodeGraph for the target version
  • workspace_root - Path to the actual workspace root
  • base_worktree_path - Path to the temporary base worktree
  • target_worktree_path - Path to the temporary target worktree
pub fn compute_changes(&self) -> Result<DiffResult>

Computes all symbol changes between base and target graphs.

Errors

Returns error if graph access fails.