pub enum ExportKind {
Named,
NamedTypeOnly,
Default,
Namespace,
NamespaceTypeOnly,
AllFromModule,
AllFromModuleTypeOnly,
Assignment,
GlobalNamespace,
}Expand description
Discriminator for different export semantics
This enum distinguishes between various export patterns found across languages, enabling precise semantic representation of module exports.
Examples
use sqry_core::graph::edge::ExportKind;
// Named export: `export { foo }`
let named = ExportKind::Named;
// Default export: `export default MyClass`
let default = ExportKind::Default;
// Wildcard re-export: `export * from './mod'`
let all = ExportKind::AllFromModule;Variants
Named
Named export: export { foo } or export { foo as bar }
- symbol = “foo” (required)
- alias = Some(“bar”) if renamed
NamedTypeOnly
Named type-only export: export type { Foo } (TypeScript)
Type-only semantics inherent in variant (no metadata needed).
- symbol = “Foo” (required)
- alias = Some(“Bar”) if renamed
Default
Default export: export default foo
- symbol = name of exported item, or “default” for anonymous
Namespace
Namespace re-export: export * as ns from './mod'
- symbol = Some(“ns”) (the namespace name, required)
from_module= “./mod”
NamespaceTypeOnly
Type-only namespace re-export: export type * as Types from './types' (TypeScript)
- symbol = Some(“Types”) (required)
from_module= “./types”
AllFromModule
Wildcard re-export: export * from './mod'
- symbol = None (NO sentinel string)
from_module= “./mod”
AllFromModuleTypeOnly
Type-only wildcard re-export: export type * from './types' (TypeScript 5.0+)
- symbol = None (NO sentinel string)
from_module= “./types”
Assignment
TypeScript assignment export: export = Foo (UMD/CJS interop)
- symbol = “Foo” (the exported binding, required)
GlobalNamespace
TypeScript global namespace augmentation: export as namespace Foo
- symbol = “Foo” (the global namespace name, required)