pub struct AnalysisCache {
pub manifest_hash: String,
pub node_id_hash: [u8; 32],
/* private fields */
}Expand description
Memory-mapped analysis cache for fast loading
Fields
manifest_hash: StringHash of the manifest file
node_id_hash: [u8; 32]Hash of node IDs for identity verification
Implementations
Sourceimpl AnalysisCache
impl AnalysisCache
Sourcepub fn load(index_path: &Path) -> Result<Self>
pub fn load(index_path: &Path) -> Result<Self>
Load analysis cache from index directory Returns an error if the operation fails.
Errors
Sourcepub fn get_csr(&self) -> Result<Arc<CsrAdjacency>>
pub fn get_csr(&self) -> Result<Arc<CsrAdjacency>>
Get CSR adjacency Returns an error if the operation fails.
Errors
Sourcepub fn get_scc(&self, kind: &EdgeKind) -> Result<Arc<SccData>>
pub fn get_scc(&self, kind: &EdgeKind) -> Result<Arc<SccData>>
Get SCC data for an edge kind (matches by discriminant, ignores metadata) Returns an error if the operation fails.
Errors
Sourcepub fn get_condensation(&self, kind: &EdgeKind) -> Result<Arc<CondensationDag>>
pub fn get_condensation(&self, kind: &EdgeKind) -> Result<Arc<CondensationDag>>
Get condensation DAG for an edge kind (matches by discriminant, ignores metadata) Returns an error if the operation fails.
Errors