pub struct UpdateReceiver { /* private fields */ }Expand description
Receiver for processing graph updates.
This should be owned by a single thread that processes updates sequentially to ensure serialization.
Implementations
Sourceimpl UpdateReceiver
impl UpdateReceiver
Sourcepub fn recv(&self) -> Result<GraphUpdate, ChannelError>
pub fn recv(&self) -> Result<GraphUpdate, ChannelError>
Receives the next update, blocking until one is available.
Errors
Returns ChannelError::Disconnected if all senders have been dropped.
Sourcepub fn try_recv(&self) -> Result<Option<GraphUpdate>, ChannelError>
pub fn try_recv(&self) -> Result<Option<GraphUpdate>, ChannelError>
Tries to receive the next update without blocking.
Returns None if no update is currently available.
Errors
Returns ChannelError::Disconnected if all senders have been dropped.
Sourcepub fn iter(&self) -> impl Iterator<Item = GraphUpdate> + '_
pub fn iter(&self) -> impl Iterator<Item = GraphUpdate> + '_
Returns an iterator over available updates.
The iterator will block waiting for updates and complete when all senders are dropped.
Sourcepub fn updates_received(&self) -> u64
pub fn updates_received(&self) -> u64
Returns the number of updates received through this channel.