pub enum FileReader {
Mmap {
file: File,
mmap: Mmap,
},
Buffered {
data: Vec<u8>,
},
}Expand description
File reader that supports both memory-mapped and buffered reading
Variants
Implementations
Sourceimpl FileReader
impl FileReader
Sourcepub fn open<P: AsRef<Path>>(path: P) -> Result<Self>
pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>
Open a file using the default policy (auto with 10MB threshold)
Errors
Returns anyhow::Error when the file cannot be opened, memory-mapped, or read.
Sourcepub fn open_with_policy<P: AsRef<Path>>(
path: P,
policy: ReaderPolicy,
) -> Result<Self>
pub fn open_with_policy<P: AsRef<Path>>( path: P, policy: ReaderPolicy, ) -> Result<Self>
Open a file with a specific reading policy
Errors
Returns anyhow::Error when file metadata access, mmap, or buffered reads fail.
Also returns error if file exceeds the maximum source file size limit (RR-10 DoS prevention).