#[non_exhaustive]pub enum IndexProgress {
Show 14 variants
Started {
total_files: usize,
},
FileProcessing {
path: PathBuf,
current: usize,
total: usize,
},
FileCompleted {
path: PathBuf,
symbols: usize,
},
IngestProgress {
files_processed: usize,
total_files: usize,
total_symbols: usize,
counts: NodeIngestCounts,
elapsed: Duration,
eta: Option<Duration>,
},
IngestFileStarted {
path: PathBuf,
current: usize,
total: usize,
},
IngestFileCompleted {
path: PathBuf,
symbols: usize,
duration: Duration,
},
StageStarted {
stage_name: &'static str,
},
StageCompleted {
stage_name: &'static str,
stage_duration: Duration,
},
GraphPhaseStarted {
phase_number: u8,
phase_name: &'static str,
total_items: usize,
},
GraphPhaseProgress {
phase_number: u8,
items_processed: usize,
total_items: usize,
},
GraphPhaseCompleted {
phase_number: u8,
phase_name: &'static str,
phase_duration: Duration,
},
SavingStarted {
component_name: &'static str,
},
SavingCompleted {
component_name: &'static str,
save_duration: Duration,
},
Completed {
total_symbols: usize,
duration: Duration,
},
}Expand description
Progress events emitted during indexing operations.
Stability
This enum is marked #[non_exhaustive] to allow adding new progress events
in future versions without breaking downstream code. Always include a
wildcard arm (_ => {}) when matching on this enum.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Started
Indexing has started.
FileProcessing
A file is currently being processed.
Fields
FileCompleted
A file has been processed successfully.
Fields
IngestProgress
Progress while ingesting nodes and relations into the index.
Fields
counts: NodeIngestCountsNode-kind breakdown
IngestFileStarted
A file is about to be ingested into the index.
Fields
IngestFileCompleted
A file has finished ingesting into the index.
Fields
StageStarted
A coarse-grained indexing stage has started.
Fields
StageCompleted
A coarse-grained indexing stage has completed.
Fields
GraphPhaseStarted
A graph build phase has started.
Fields
GraphPhaseProgress
Progress within a graph build phase.
Fields
GraphPhaseCompleted
A graph build phase has completed.
Fields
SavingStarted
Index save operation has started for a component.
Fields
SavingCompleted
Index save operation has completed for a component.
Fields
Completed
Indexing has completed.