pub struct DuplicateGroup {
pub hash: u64,
pub body_hash_128: Option<BodyHash128>,
pub node_ids: Vec<NodeId>,
}Expand description
A group of duplicate symbols
Fields
hash: u64Hash identifying this group (64-bit, for backward compatibility)
body_hash_128: Option<BodyHash128>Full 128-bit body hash (only set for body duplicate groups)
This is used for proper hex string output in CLI/MCP. When set, this is the actual body hash from the indexed nodes.
node_ids: Vec<NodeId>Node IDs of duplicates in this group