Shared relation extraction infrastructure for language plugins Shared relation extraction infrastructure for language plugins.
This module provides common utilities used by all language plugins:
identity- Call identity building utilitiesqueries- Tree-sitter query helperstypes- Synthetic name generation
Re-exports
pub use identity::CallIdentityBuilder;pub use identity::CallIdentityKind;pub use identity::CallIdentityMetadata;pub use types::SyntheticNameBuilder;