pub struct CollectorTimedUse<'a> { /* private fields */ }Expand description
RAII timer for collector - records event with duration on drop
Created via UsesCollector::timed(). When dropped, records the event
with the elapsed duration since creation.
Implementations
Sourceimpl<'a> CollectorTimedUse<'a>
impl<'a> CollectorTimedUse<'a>
Sourcepub fn cancel(&mut self)
pub fn cancel(&mut self)
Cancel the timer without recording an event
Use this when an operation fails and you don’t want to record it.
Sourcepub fn complete_with(self, event_type: UseEventType)
pub fn complete_with(self, event_type: UseEventType)
Complete the timer with an updated event type
Use this when you need to update the event type after the operation completes (e.g., to update result count).