Error types for programmatic tool integration Structured error types for programmatic tool integration
This module provides standardized error codes and responses that enable programmatic consumers to handle failures gracefully and suggest actionable fixes.
Structs
- Error
Response - Structured error response for JSON output
Enums
- Error
Code - Standardized error codes for tool integration
Type Aliases
- Tool
Result - Result type using
ErrorResponse