pub struct SafeParserConfig { /* private fields */ }Expand description
Configuration for SafeParser with bounded limits.
All limits are bounded to prevent users from disabling security protections. Values outside the allowed range are clamped to the nearest bound.
Bounds
max_input_size: [1 MiB, 32 MiB]timeout_micros: [100,000 µs, 5,000,000 µs] (100ms to 5s)
Example
use sqry_core::plugin::safe_parse::SafeParserConfig;
// Use defaults
let config = SafeParserConfig::default();
assert_eq!(config.max_input_size(), 10 * 1024 * 1024);
assert_eq!(config.timeout_micros(), 2_000_000);
// Custom configuration (values are clamped to bounds)
let config = SafeParserConfig::new()
.with_max_input_size(20 * 1024 * 1024)
.with_timeout_micros(3_000_000);Implementations
Sourceimpl SafeParserConfig
impl SafeParserConfig
Sourcepub fn with_max_input_size(self, size: usize) -> Self
pub fn with_max_input_size(self, size: usize) -> Self
Set maximum input size in bytes.
Value is clamped to [1 MiB, 32 MiB].
Sourcepub fn with_timeout_micros(self, timeout: u64) -> Self
pub fn with_timeout_micros(self, timeout: u64) -> Self
Set parse timeout in microseconds.
Value is clamped to [100,000 µs, 5,000,000 µs].
Sourcepub fn max_input_size(&self) -> usize
pub fn max_input_size(&self) -> usize
Get current maximum input size.
Sourcepub fn timeout_micros(&self) -> u64
pub fn timeout_micros(&self) -> u64
Get current timeout in microseconds.